Crate s2_pmtiles

source ·
The s2-pmtiles Rust crate provides functionalities to read and write S2-PMTiles Spec messages. This crate supports no_std and is intended to be used in embedded systems and WASM applications.

Re-exports

Modules

  • All encoding and decoding is done via u64. So all types must implement this trait to be able to be encoded and decoded.
  • The Buffer struct is used to read and write Buffer messages.
  • A simple cache system with a maximum size.
  • The PMTiles specification tools
  • The S2PMTiles tool for reading S2PMTiles and PMTiles messages
  • The S2PMTiles specification tools
  • The S2PMTiles tool for writing S2PMTiles and PMTiles messages